# -*- coding: utf-8 -*-
##################################################
# This file is part of WAPT Enterprise
# All right reserved, (c) Tranquil IT Systems 2024
# For more information please refer to
# https://wapt.tranquil.it/store/licences.html
##################################################
from setuphelpers import *
from setupdevhelpers import *
import requests
import waptlicences


def update_package():
    # Declaring local variables
    package_updated = False
    proxies = get_proxies_from_wapt_console()
    if not proxies:
        proxies = get_proxies()

    url_base = "https://devolutions.net/remote-desktop-manager/home/download/"
    response = requests.get(url_base, allow_redirects=True, proxies=proxies)

    # Utilisation de bs_find_all pour extraire les versions et trouver la plus récente
    divs = bs_find_all(response.text, "div", "class", "version", proxies=proxies)
    latest_version = ".".join(
        map(str, max(tuple(map(int, div.text.split(": ")[1].split("."))) for div in divs if "Version:" in div.text))
    )

    download_url = "https://cdn.devolutions.net/download/Setup.RemoteDesktopManagerAgent.%s.msi" %latest_version
    msi_file = download_url.split("/")[-1]

    # Supprimer les anciens fichiers binaires
    for f in glob.glob("*.msi"):
        if f != msi_file:
            remove_file(f)

    if not isfile(msi_file):
        print("Downloading: %s" % msi_file)
        wget( download_url, msi_file, proxies=proxies)
    else:
        print("Binary is present: %s" % msi_file)

    expected_issuer = 'Devolutions Inc'
    sign_name = waptlicences.check_msi_signature(msi_file)[0]
    if sign_name != expected_issuer:
        error(f'Bad issuer {sign_name} != {expected_issuer} ')

    
    version = get_version_from_binary(msi_file)
    # Mettre à jour le package
    control.set_software_version(version)
    control.save_control_to_wapt()   
     
    return package_updated
    
